==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24AlignmentAction.h <==
// public class javax.swing.text.StyledEditorKit$AlignmentAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 850d7bc247ab0a7e javax_swing_text_StyledEditorKit__24AlignmentAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods	javax_swing_text_StyledEditorKit__24AlignmentAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs	javax_swing_text_StyledEditorKit__24AlignmentAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs {
	jint	a;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24AlignmentAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object {
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24AlignmentAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24AlignmentAction.h <==
// public class javax.swing.text.StyledEditorKit$AlignmentAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 850d7bc247ab0a7e javax_swing_text_StyledEditorKit__24AlignmentAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vmethods	javax_swing_text_StyledEditorKit__24AlignmentAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_refs	javax_swing_text_StyledEditorKit__24AlignmentAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs {
	jint	a;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24AlignmentAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$object {
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24AlignmentAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$vtype _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24AlignmentAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24AlignmentAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24AlignmentAction_H_ */
